summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/main/java/org/bukkit/entity/LivingEntity.java16
1 files changed, 12 insertions, 4 deletions
diff --git a/src/main/java/org/bukkit/entity/LivingEntity.java b/src/main/java/org/bukkit/entity/LivingEntity.java
index 2bc90bef..09f532f5 100644
--- a/src/main/java/org/bukkit/entity/LivingEntity.java
+++ b/src/main/java/org/bukkit/entity/LivingEntity.java
@@ -12,18 +12,26 @@ import org.bukkit.block.Block;
public interface LivingEntity extends Entity {
/**
* Gets the entity's health from 0-20, where 0 is dead and 20 is full
*
* @return Health represented from 0-20
*/
public int getHealth();
/**
* Sets the entity's health from 0-20, where 0 is dead and 20 is full
*
- * @param health New health represented from 0-20
+ * @param health New health represented from 0 to max
+ * @throws IllegalArgumentException Thrown if the health is < 0 or > max
*/
public void setHealth(int health);
+
+ /**
+ * Gets the maximum health this entity may have
+ *
+ * @return Maximum health
+ */
+ public int getMaxHealth();
/**
* Gets the height of the entity's head above its Location
@@ -12,18 +12,26 @@ import org.bukkit.block.Block;
public interface LivingEntity extends Entity {
/**
- * Gets the entity's health from 0-20, where 0 is dead and 20 is full
+ * Gets the entity's health from 0 to {@link #getMaxHealth()}, where 0 is dead
*
@@ -12,18 +12,26 @@ import org.bukkit.block.Block;
*
- * @return Health represented from 0-20
+ * @return Health represented from 0 to max
*/
public int getHealth();
@@ -12,18 +12,26 @@ import org.bukkit.block.Block;
public int getHealth();
/**
- * Sets the entity's health from 0-20, where 0 is dead and 20 is full
+ * Sets the entity's health from 0 to {@link #getMaxHealth()}, where 0 is dead
*